unit ANICursorListDlg; { Animated cursor list component editor dialog
                         c. LeslieSoft 1997-1999, lsoft@ax.hu }

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Grids, StdCtrls, Buttons;

type
  TANICursorListEditorDlg = class(TForm)
    StringGrid: TStringGrid;
    ButtonAdd: TButton;
    ButtonDelete: TButton;
    ButtonClose: TButton;
    OpenDialog: TOpenDialog;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    SpeedButtonUp: TSpeedButton;
    SpeedButtonDown: TSpeedButton;
    procedure FormCreate(Sender: TObject);
    procedure StringGridDrawCell(Sender: TObject; ACol, ARow: Integer; Rect: TRect; State: TGridDrawState);
    procedure FormShow(Sender: TObject);
    procedure ButtonAddClick(Sender: TObject);
    procedure ButtonDeleteClick(Sender: TObject);
    procedure SpeedButtonUpClick(Sender: TObject);
    procedure SpeedButtonDownClick(Sender: TObject);
    procedure StringGridClick(Sender: TObject);
  public
    Component : TComponent;
    Designer  : TDesigner;
  end;

var
  ANICursorListEditorDlg: TANICursorListEditorDlg;

implementation

uses
  ANICursorList;

{$R *.DFM}

procedure TANICursorListEditorDlg.FormCreate(Sender: TObject);
begin
  { Setup string grid column widths }
  with StringGrid do
    begin
      ColWidths[0] := 24;
      ColWidths[1] := 32;
      ColWidths[2] := (Width - ColWidths[0] - ColWidths[1] - 7 - 17) div 2;
      ColWidths[3] := ColWidths[2];
    end;
end;

procedure TANICursorListEditorDlg.StringGridDrawCell(Sender: TObject; ACol,ARow: Integer; Rect: TRect; State: TGridDrawState);
var
  XBrush : TBrush;
begin
  if ARow < (Component as TANICursorList).Count then
    with StringGrid, Canvas do
      case ACol of
        { Draw the index number }
        0 : TextOut(Rect.Left,Rect.Top,IntToStr(ARow));
        { Draw the first icon of the cursor on a solid white background }
        1 : begin
              XBrush := TBrush.Create;
              try
                XBrush.Color := clWhite;
                (Component as TANICursorList).DrawIcon(ARow,0,Canvas,Rect.Left,Rect.Top,RowHeights[ARow],RowHeights[ARow],XBrush);
              finally
                XBrush.Free;
              end;
            end;
        { Draw the title string }
        2 : DrawText(Handle,@(Component as TANICursorList).Title[ARow][1],Length((Component as TANICursorList).Title[ARow]),Rect,DT_WORDBREAK);
        { Draw the author string }
        3 : DrawText(Handle,@(Component as TANICursorList).Author[ARow][1],Length((Component as TANICursorList).Author[ARow]),Rect,DT_WORDBREAK);
      end;
end;

procedure TANICursorListEditorDlg.FormShow(Sender: TObject);
begin
  { Setup string grid }
  StringGrid.RowCount := (Component as TANICursorList).Count;
  StringGrid.Row := 0;
  { Setup Delete button state }
  ButtonDelete.Enabled := (Component as TANICursorList).Count > 0;
  { Setup move button states }
  SpeedButtonDown.Enabled := StringGrid.Row < (Component as TANICursorList).Count-1;
  SpeedButtonUp.Enabled := StringGrid.Row > 0;
end;

procedure TANICursorListEditorDlg.ButtonAddClick(Sender: TObject);
var
  I,J : Integer;
begin
  OpenDialog.FileName := '';
  if OpenDialog.Execute then
    begin
      (Component as TANICursorList).BeginUpdate;
      { Add all selected animated cursors }
      J := 0;
      for I := 0 to OpenDialog.Files.Count-1 do
        J := (Component as TANICursorList).Add(OpenDialog.Files[I]);
      (Component as TANICursorList).EndUpdate;
      { Setup string grid }
      StringGrid.RowCount := (Component as TANICursorList).Count;
      StringGrid.Row := J;
      { Redraw string grid }
      StringGrid.Refresh;
      { Setup Delete button state }
      ButtonDelete.Enabled := (Component as TANICursorList).Count > 0;
      { Setup move button states }
      SpeedButtonDown.Enabled := StringGrid.Row < (Component as TANICursorList).Count-1;
      SpeedButtonUp.Enabled := StringGrid.Row > 0;
      { The component is modified }
      Designer.Modified;
    end;
end;

procedure TANICursorListEditorDlg.ButtonDeleteClick(Sender: TObject);
begin
  { Delete selected cursor }
  (Component as TANICursorList).Delete(StringGrid.Row);
  { Setup string grid row count }
  StringGrid.RowCount := (Component as TANICursorList).Count;
  { Redraw string grid }
  StringGrid.Refresh;
  { Setup Delete button state }
  ButtonDelete.Enabled := (Component as TANICursorList).Count > 0;
  { Setup move button states }
  SpeedButtonDown.Enabled := StringGrid.Row < (Component as TANICursorList).Count-1;
  SpeedButtonUp.Enabled := StringGrid.Row > 0;
  { The component is modified }
  Designer.Modified;
end;

procedure TANICursorListEditorDlg.SpeedButtonUpClick(Sender: TObject);
begin
  (Component as TANICursorList).Move(StringGrid.Row,StringGrid.Row-1);
  StringGrid.Row := StringGrid.Row-1;
  StringGrid.Refresh;
  { Setup move button states }
  SpeedButtonDown.Enabled := StringGrid.Row < (Component as TANICursorList).Count-1;
  SpeedButtonUp.Enabled := StringGrid.Row > 0;
  { The component is modified }
  Designer.Modified;
end;

procedure TANICursorListEditorDlg.SpeedButtonDownClick(Sender: TObject);
begin
  (Component as TANICursorList).Move(StringGrid.Row,StringGrid.Row+1);
  StringGrid.Row := StringGrid.Row+1;
  StringGrid.Refresh;
  { Setup move button states }
  SpeedButtonDown.Enabled := StringGrid.Row < (Component as TANICursorList).Count-1;
  SpeedButtonUp.Enabled := StringGrid.Row > 0;
  { The component is modified }
  Designer.Modified;
end;

procedure TANICursorListEditorDlg.StringGridClick(Sender: TObject);
begin
  { Setup move button states }
  SpeedButtonDown.Enabled := StringGrid.Row < (Component as TANICursorList).Count-1;
  SpeedButtonUp.Enabled := StringGrid.Row > 0;
end;

end.
